import {processesSchema} from "./schemas/processes";
import {ProcessesResponseInterface} from "./responses/processes";
import {SchemaClient} from "../schema-client";
import {GetProcessesRequest} from "./requests/get-processes";
import {PaginationRequest} from "./requests/pagination";
import {ResponseInterface} from "./responses/response";
import {CommandResponseInterface} from "./responses/comamnds";
import commandsSchema from "./schemas/commands";
import runCommandsSchema from "./schemas/run-commands";
import {RepeatProcessRequest} from "./requests/repeat-process";
import repeatProcessSchema from "./schemas/repeat-process";
import processOutputSchema from "./schemas/process-output";
import {ProcessOutputRequest} from "./requests/process-ouput";
import playProcessSchema from "./schemas/play-process";
import pauseProcessSchema from "./schemas/pause-process";
import stopProcessSchema from "./schemas/stop-process";
import killProcessSchema from "./schemas/kill-process";
import commandSchema from "./schemas/command";

export class SMClient {
    schemaClient: SchemaClient

    constructor() {
        this.schemaClient = new SchemaClient({
            baseUrl: 'http://fmw.sipachev.sv'
        })
    }

    async getCommands(): Promise<ResponseInterface<CommandResponseInterface[]>> {
        let { responseData, headers } = await this.schemaClient.send(commandsSchema, {})
        return {
            data: responseData,
            headers: headers
        }
    }

    async getCommand(name: string): Promise<ResponseInterface<CommandResponseInterface>> {
        let { responseData, headers } = await this.schemaClient.send(commandSchema, {
            commandName: name
        })
        return {
            data: responseData,
            headers: headers
        }
    }

    async runCommand(data: any): Promise<ResponseInterface> {
        let { headers } = await this.schemaClient.send(runCommandsSchema, data)
        return {
            data: null,
            headers: headers
        }
    }

    async getProcesses(data: GetProcessesRequest | PaginationRequest): Promise<ResponseInterface<ProcessesResponseInterface[]>> {
        let { responseData, headers } = await this.schemaClient.send(processesSchema, data)
        return {
            data: responseData,
            headers: headers
        }
    }

    async repeatProcess(data: RepeatProcessRequest): Promise<ResponseInterface> {
        let { responseData, headers } = await this.schemaClient.send(repeatProcessSchema, data)
        return {
            data: responseData as ProcessesResponseInterface[],
            headers: headers
        }
    }

    async getProcessOutput(data: ProcessOutputRequest): Promise<ResponseInterface> {
        let { responseData, headers } = await this.schemaClient.send(processOutputSchema, data)
        return {
            data: responseData,
            headers: headers
        }
    }

    async playProcess(id: string): Promise<ResponseInterface> {
        let { headers } = await this.schemaClient.send(playProcessSchema, {id})
        return {
            data: null,
            headers: headers
        }
    }

    async pauseProcess(id: string): Promise<ResponseInterface> {
        let { headers } = await this.schemaClient.send(pauseProcessSchema, {id})
        return {
            data: null,
            headers: headers
        }
    }

    async stopProcess(id: string): Promise<ResponseInterface> {
        let { headers } = await this.schemaClient.send(stopProcessSchema, {id})
        return {
            data: null,
            headers: headers
        }
    }

    async killProcess(id: string): Promise<ResponseInterface> {
        let { headers } = await this.schemaClient.send(killProcessSchema, {id})
        return {
            data: null,
            headers: headers
        }
    }
}

export let smClient = new SMClient
export default smClient
